==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ChartSeriesEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { ChartSeriesEventArgsDescription } from "./ChartSeriesEventArgsDescription";
/**
 * @hidden
 */
var ChartSeriesEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ChartSeriesEventArgsDescriptionMetadata, _super);
    function ChartSeriesEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChartSeriesEventArgsDescriptionMetadata.b = function (a) {
        if (ChartSeriesEventArgsDescriptionMetadata.a == null) {
            ChartSeriesEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChartSeriesEventArgsDescriptionMetadata.c(ChartSeriesEventArgsDescriptionMetadata.a);
        }
        if (a.j(ChartSeriesEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ChartSeriesEventArgsDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    ChartSeriesEventArgsDescriptionMetadata.c = function (a) {
        a.item("Series", "ExportedType:Series");
    };
    ChartSeriesEventArgsDescriptionMetadata.d = function (a) {
        ChartSeriesEventArgsDescriptionMetadata.b(a);
        a.aa("ChartSeriesEventArgs", function () { return new ChartSeriesEventArgsDescription(); });
        a.z("ChartSeriesEventArgs", ChartSeriesEventArgsDescriptionMetadata.a);
    };
    ChartSeriesEventArgsDescriptionMetadata.$t = markType(ChartSeriesEventArgsDescriptionMetadata, 'ChartSeriesEventArgsDescriptionMetadata');
    ChartSeriesEventArgsDescriptionMetadata.a = null;
    return ChartSeriesEventArgsDescriptionMetadata;
}(Base));
export { ChartSeriesEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ChartSeriesEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { ChartSeriesEventArgsDescription } from "./ChartSeriesEventArgsDescription";
/**
 * @hidden
 */
var ChartSeriesEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ChartSeriesEventArgsDescriptionMetadata, _super);
    function ChartSeriesEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChartSeriesEventArgsDescriptionMetadata.b = function (a) {
        if (ChartSeriesEventArgsDescriptionMetadata.a == null) {
            ChartSeriesEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChartSeriesEventArgsDescriptionMetadata.c(ChartSeriesEventArgsDescriptionMetadata.a);
        }
        if (a.k(ChartSeriesEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(ChartSeriesEventArgsDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    ChartSeriesEventArgsDescriptionMetadata.c = function (a) {
        a.item("Series", "ExportedType:Series");
    };
    ChartSeriesEventArgsDescriptionMetadata.d = function (a) {
        ChartSeriesEventArgsDescriptionMetadata.b(a);
        a.ac("ChartSeriesEventArgs", function () { return new ChartSeriesEventArgsDescription(); });
        a.ab("ChartSeriesEventArgs", ChartSeriesEventArgsDescriptionMetadata.a);
    };
    ChartSeriesEventArgsDescriptionMetadata.$t = markType(ChartSeriesEventArgsDescriptionMetadata, 'ChartSeriesEventArgsDescriptionMetadata');
    ChartSeriesEventArgsDescriptionMetadata.a = null;
    return ChartSeriesEventArgsDescriptionMetadata;
}(Base));
export { ChartSeriesEventArgsDescriptionMetadata };
